package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TKufangMapper;
import com.ruoyi.system.domain.TKufang;
import com.ruoyi.system.service.ITKufangService;

/**
 * 库房Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-02-20
 */
@Service
public class TKufangServiceImpl implements ITKufangService 
{
    @Autowired
    private TKufangMapper tKufangMapper;

    /**
     * 查询库房
     * 
     * @param id 库房主键
     * @return 库房
     */
    @Override
    public TKufang selectTKufangById(Long id)
    {
        return tKufangMapper.selectTKufangById(id);
    }

    /**
     * 查询库房列表
     * 
     * @param tKufang 库房
     * @return 库房
     */
    @Override
    public List<TKufang> selectTKufangList(TKufang tKufang)
    {
        return tKufangMapper.selectTKufangList(tKufang);
    }

    /**
     * 新增库房
     * 
     * @param tKufang 库房
     * @return 结果
     */
    @Override
    public int insertTKufang(TKufang tKufang)
    {
        tKufang.setCreateTime(DateUtils.getNowDate());
        return tKufangMapper.insertTKufang(tKufang);
    }

    /**
     * 修改库房
     * 
     * @param tKufang 库房
     * @return 结果
     */
    @Override
    public int updateTKufang(TKufang tKufang)
    {
        return tKufangMapper.updateTKufang(tKufang);
    }

    /**
     * 批量删除库房
     * 
     * @param ids 需要删除的库房主键
     * @return 结果
     */
    @Override
    public int deleteTKufangByIds(Long[] ids)
    {
        return tKufangMapper.deleteTKufangByIds(ids);
    }

    /**
     * 删除库房信息
     * 
     * @param id 库房主键
     * @return 结果
     */
    @Override
    public int deleteTKufangById(Long id)
    {
        return tKufangMapper.deleteTKufangById(id);
    }

    @Override
    public List<Map<String, Object>> getUserByRole() {
        return tKufangMapper.getUserByRole();
    }
}
