package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TKufang;
import com.ruoyi.system.service.ITKufangService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 库房Controller
 * 
 * @author ruoyi
 * @date 2024-02-20
 */
@RestController
@RequestMapping("/system/kufang")
public class TKufangController extends BaseController
{
    @Autowired
    private ITKufangService tKufangService;

    /**
     * 查询库房列表
     */
    @PreAuthorize("@ss.hasPermi('system:kufang:list')")
    @GetMapping("/list")
    public TableDataInfo list(TKufang tKufang)
    {
        startPage();
        List<TKufang> list = tKufangService.selectTKufangList(tKufang);
        return getDataTable(list);
    }

    /**
     * 导出库房列表
     */
    @PreAuthorize("@ss.hasPermi('system:kufang:export')")
    @Log(title = "库房", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TKufang tKufang)
    {
        List<TKufang> list = tKufangService.selectTKufangList(tKufang);
        ExcelUtil<TKufang> util = new ExcelUtil<TKufang>(TKufang.class);
        util.exportExcel(response, list, "库房数据");
    }

    /**
     * 获取库房详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:kufang:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tKufangService.selectTKufangById(id));
    }

    /**
     * 新增库房
     */
    @PreAuthorize("@ss.hasPermi('system:kufang:add')")
    @Log(title = "库房", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TKufang tKufang)
    {
        return toAjax(tKufangService.insertTKufang(tKufang));
    }

    /**
     * 修改库房
     */
    @PreAuthorize("@ss.hasPermi('system:kufang:edit')")
    @Log(title = "库房", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TKufang tKufang)
    {
        return toAjax(tKufangService.updateTKufang(tKufang));
    }

    /**
     * 删除库房
     */
    @PreAuthorize("@ss.hasPermi('system:kufang:remove')")
    @Log(title = "库房", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tKufangService.deleteTKufangByIds(ids));
    }

    @GetMapping(value = "/getUserByRole")
    public AjaxResult getUserByRole() {
        return success(tKufangService.getUserByRole());
    }
}
